@@ -21,8 +21,6 @@ extern int lockhome;
 extern int nodotfiles;
 extern int bind_port_fd;
 
-extern const unsigned startup_code;
-
 /* In backend.c */
 extern void show_message_file(unsigned code);
 extern int handle_pass(void);
@@ -60,6 +58,9 @@ extern int parse_remoteip(const char*);
 extern int handle_size(void);
 extern int handle_mdtm(void);
 
+/* In statmod.c */
+extern int handle_mdtm2(void);
+
 /* In state.c */
 extern int binary_flag;
 extern int handle_type(void);
@@ -70,6 +71,7 @@ extern int handle_pwd(void);
 extern int handle_cdup(void);
 
 /* In store.c */
+extern int store_exclusive;
 extern int handle_stor(void);
 extern int handle_appe(void);
 extern int handle_mkd(void);
