@@ -80,16 +80,16 @@ run_compare_test() {
   local name=$1
   shift
   sed -e "s:@SOURCE@:$src:g"   	-e "s:@TMPDIR@:$tmp:g"   	-e "s:@UID@:$_UID:" 	-e "s:@GID@:$_GID:" 	>$tmp/expected
-  ( runtest "$@" ) 2>&1 >$tmp/actual-raw
+  ( runtest "$@" 2>&1 ) 2>&1 >$tmp/actual-raw
   cat -v $tmp/actual-raw >$tmp/actual
   if ! cmp $tmp/expected $tmp/actual >/dev/null 2>&1
   then
     echo "Test $name $@ failed:"
 	( cd $tmp; diff -U 9999 expected actual | tail -n +3; echo; )
-	let tests_failed=tests_failed+1
+	tests_failed=$(($tests_failed+1))
   fi
   rm -f $tmp/expected $tmp/actual
-  let tests_count=tests_count+1
+  tests_count=$(($tests_count+1))
 }
 
 ##### Test tests/auth-commands #####
@@ -264,9 +264,14 @@ END_OF_TEST_RESULTS
 ##### Test tests/auth-timeout #####
 
 runtest() {
-TIMEOUT=60 auth 1 2
-TIMEOUT=00 auth 1 2
-TIMEOUT=-6 auth 1 2
+export TIMEOUT
+TIMEOUT=60
+auth 1 2
+TIMEOUT=00
+auth 1 2
+TIMEOUT=-6
+auth 1 2
+unset TIMEOUT
 }
 run_compare_test tests/auth-timeout  <<END_OF_TEST_RESULTS
 220-TwoFTPd server ready.^M
@@ -295,7 +300,7 @@ END_OF_TEST_RESULTS
 runtest() {
 mkdir $home/subdir
 date >$home/subdir/date
-for i in {0,1,2,3,4,5}{0,1,2,3,4,5,6,7,8,9}; do
+for i in `seq 60`; do
   echo 01234567890123456789012345678901234567890123456789012345678901234567890
 done >$home/large
 TZ=GMT touch -t 200001020304.05 $home/empty
@@ -2122,7 +2127,7 @@ END_OF_TEST_RESULTS
 ##### Test tests/auth-cvm-bad-data #####
 
 runtest() {
-auth $cvm 'printf Help!' 'USER username' 'PASS password'
+auth $cvm 'printf Help' 'USER username' 'PASS password'
 }
 run_compare_test tests/auth-cvm-bad-data  <<END_OF_TEST_RESULTS
 220-TwoFTPd server ready.^M
@@ -2148,14 +2153,14 @@ END_OF_TEST_RESULTS
 runtest() {
 makecvm 'cat >/dev/null' \
 	'printf "\\0"' \
-	'printf "\\0001username\\0"' \
-	'printf "\\0002102\\0"' \
-	'printf "\\0003103\\0"' \
-	'printf "\\0004Real Name\\0"' \
-	'printf "\\0005/home/dir\\0"' \
-	'printf "\\0006/bin/false\\0"' \
-	'printf "\\0007grpname\\0"' \
-	'printf "\\0000"' \
+	'printf "\\001username\\0"' \
+	'printf "\\002102\\0"' \
+	'printf "\\003103\\0"' \
+	'printf "\\004Real Name\\0"' \
+	'printf "\\005/home/dir\\0"' \
+	'printf "\\006/bin/false\\0"' \
+	'printf "\\007grpname\\0"' \
+	'printf "\\000"' \
 	'exit 0'
 }
 run_compare_test tests/make-good-cvm  <<END_OF_TEST_RESULTS
